@@ -1443,6 +1443,30 @@ class Rediz(RedizConventions):
         return data[0] if singular else data
 
     def _get_summary_implementation(self,name):
-        derived = self.derived_names(name)
-        derived_data = dict( [ (k,self.get(v)) for k,v in derived.items() ] )
-        return derived_data
\ No newline at end of file
+        def shorten(obj):
+            if isinstance(obj,list):
+                return obj[:5]
+            elif isinstance(obj,dict):
+                return dict( [ (k,shorten(v)) for k,v in obj.items() ])
+            else:
+                return obj
+        def delay_level(name,delay):
+            things = [ self.performance_name(name=name,delay=delay), self.delayed_name(name=name,delay=delay),self.links_name(name=name,delay=delay),
+                       self.cdf_name(name=name,delay=delay)]
+            return dict([(thing, shorten(self.get(thing))) for thing in things])
+
+        def top_level(name):
+            things = [name, self.lagged_values_name(name), self.lagged_times_name(name),
+                         self.backlinks_name(name), self.subscribers_name(name),
+                         self.subscriptions_name(name), self.history_name(name),
+                         self.messages_name(name), self.performance_name(name=name) ]
+            return dict( [ ( thing,shorten(self.get(thing)) ) for thing in things ])
+
+        tl = top_level(name)
+        for delay in self.DELAYS:
+            tl['delay_'+str(delay)] = delay_level(name=name,delay=delay)
+        return tl
+
+
+
+
