@@ -5,6 +5,7 @@ import numpy as np
 import threezaconventions.crypto
 from redis.client import list_or_args
 from typing import List, Union, Any, Optional
+import random
 
 KeyList   = List[Optional[str]]
 NameList  = List[Optional[str]]
@@ -183,14 +184,35 @@ class RedizConventions(object):
         return threezaconventions.crypto.hash5(s)
 
     @staticmethod
-    def vanity_key(head):
-        assert len(head)<=8 and len(head)>=4
+    def vanity_words():
+        words = ['f1eece','feedab1e','bef1eaed','1abe1ed','facade','defaced','daffed','cabbed','baff1ed','accede','2faced','faded','beaded','decade','ebbed',
+             'acceded','effaced','ceded','cecae','feed','fade','face','deed','deaf','dada','dada007',
+             'debac1e','decada1','1eafed','fab1ed','dabb1e','cab1ed','1aced','b1eed','1ead','b1ade','f1ea',
+             'flee','beef','babe','ee1','dad','deadfa11','fadab1e','1ad1ed','be1aced','class','leadless','fleeces',
+                 'deceased','seeled','sealed','scales','felled','leafless','scaled','ladles','easel','decaf','called','sell','self']
+        return [ w.replace('s','5').replace('l','1') for w in words]
+
+    @staticmethod
+    def vanity_key(head=None):
+        head = head or random.choice(RedizConventions.vanity_words())
         assert all( [c in "0123456789abcdef-" for c in head] ),'Must be a,b,c,d,e,f or digits '
         remaining = 100000
+        print(head)
         while remaining:
+            remaining = remaining-1
             write_key = RedizConventions.random_key()
             code = RedizConventions.hash(write_key)
-            if code[9:9+len(head)]==head:
+            if code[:len(head)]==head:
+                return write_key
+
+    @staticmethod
+    def feed_key():
+        remaining = 100000
+        while remaining:
+            remaining = remaining - 1
+            write_key = RedizConventions.random_key()
+            code = RedizConventions.hash(write_key)
+            if code[9:13]=='feed':
                 return write_key
 
     @staticmethod
